@@ -732,7 +732,13 @@ color_combo_class_init (GtkhtmlColorComboClass *class)
 		PROP_POPUP_SHOWN,
 		g_param_spec_boolean (
 			"popup-shown",
+			/* Translators: This is the nickname for a
+			 * GtkhtmlColorCombo property named "popup-shown",
+			 * based on a similar property in GtkComboBox. */
 			_("Popup shown"),
+			/* Translators: This is the blurb for a
+			 * GtkhtmlColorCombo property named "popup-shown",
+			 * based on a similar property in GtkComboBox. */
 			_("Whether the combo's dropdown is shown"),
 			FALSE,
 			G_PARAM_READWRITE));
@@ -742,8 +748,16 @@ color_combo_class_init (GtkhtmlColorComboClass *class)
 		PROP_STATE,
 		g_param_spec_object (
 			"state",
+			/* Translators: This is the nickname for a
+			GtkHtmlColorCombo property named "state". It holds all
+			the internal values for a GtkHtml color combination box.
+			*/
 			_("Color state"),
-			_("State of the color combo"),
+			/* Translators: This is the blurb for a
+			GtkHtmlColorCombo property named "state". It holds all
+			the internal values for a GtkHtml color combination box.
+			*/
+			_("The state of a color combo box"),
 			GTKHTML_TYPE_COLOR_STATE,
 			G_PARAM_READWRITE));
 
