@@ -1040,10 +1040,18 @@ gtkhtml_editor_set_changed (GtkhtmlEditor *editor,
 
 	g_return_if_fail (GTKHTML_IS_EDITOR (editor));
 
-	html = gtkhtml_editor_get_html (editor);
+	if (!changed) {
+		html = gtkhtml_editor_get_html (editor);
 
-	if (!changed)
-		html_engine_saved (html->engine);
+		/* XXX The NULL check was added to deal with a race in
+		 *     Evolution when saving a message to a remote Drafts
+		 *     folder (which is asynchronous) and then closing the
+		 *     editor (which is immediate).  The GtkHTML object
+		 *     may already be disposed by the time the Save Draft
+		 *     callback gets here.  See bug #553995 for details. */
+		if (html)
+			html_engine_saved (html->engine);
+	}
 
 	editor->priv->changed = changed;
 }
@@ -1546,6 +1554,28 @@ gtkhtml_editor_insert_html (GtkhtmlEditor *editor,
 	gtk_html_insert_html (html, html_text);
 }
 
+/* inserts local files only, as inlined */
+void
+gtkhtml_editor_insert_image	(GtkhtmlEditor *editor,
+				 const gchar *filename_uri)
+{
+	GtkHTML *html;
+
+	g_return_if_fail (GTKHTML_IS_EDITOR (editor));
+	g_return_if_fail (filename_uri != NULL);
+
+	html = gtkhtml_editor_get_html (editor);
+
+	if (html) {
+		HTMLObject *image;
+		
+		image = html_image_new (
+			html_engine_get_image_factory (html->engine), filename_uri,
+			NULL, NULL, 0, 0, 0, 0, 0, NULL, HTML_VALIGN_NONE, FALSE);
+		html_engine_paste_object (html->engine, image, 1);
+	}
+}
+
 gboolean
 gtkhtml_editor_search_by_data (GtkhtmlEditor *editor,
                                glong level,
