@@ -109,26 +109,23 @@ face_tool_button_reposition_window (GtkhtmlFaceToolButton *button)
 	GdkScreen *screen;
 	GdkWindow *window;
 	GdkRectangle monitor;
-	GtkAllocation allocation;
 	gint monitor_num;
 	gint x, y, width, height;
 
+	window = GTK_WIDGET (button)->window;
 	screen = gtk_widget_get_screen (GTK_WIDGET (button));
-	window = gtk_widget_get_window (GTK_WIDGET (button));
 	monitor_num = gdk_screen_get_monitor_at_window (screen, window);
 	gdk_screen_get_monitor_geometry (screen, monitor_num, &monitor);
 
 	gdk_window_get_origin (window, &x, &y);
 
-	if (!gtk_widget_get_has_window (GTK_WIDGET (button))) {
-		gtk_widget_get_allocation (GTK_WIDGET (button), &allocation);
-		x += allocation.x;
-		y += allocation.y;
+	if (GTK_WIDGET_NO_WINDOW (button)) {
+		x += GTK_WIDGET (button)->allocation.x;
+		y += GTK_WIDGET (button)->allocation.y;
 	}
 
-	gtk_widget_get_allocation (button->priv->window, &allocation);
-	width = allocation.width;
-	height = allocation.height;
+	width = button->priv->window->allocation.width;
+	height = button->priv->window->allocation.height;
 
 	x = CLAMP (x, monitor.x, monitor.x + monitor.width - width);
 	y = CLAMP (y, monitor.y, monitor.y + monitor.height - height);
@@ -149,11 +146,7 @@ face_tool_button_face_release_event_cb (GtkhtmlFaceToolButton *button,
                                         GdkEventButton *event,
                                         GtkButton *face_button)
 {
-	GtkStateType state;
-
-	state = gtk_widget_get_state (GTK_WIDGET (button));
-
-	if (state != GTK_STATE_NORMAL)
+	if (GTK_WIDGET_STATE (button) != GTK_STATE_NORMAL)
 		gtk_button_clicked (face_button);
 
 	return FALSE;
@@ -331,7 +324,7 @@ face_tool_button_popup (GtkhtmlFaceToolButton *button)
 	GdkWindow *window;
 	GdkGrabStatus status;
 
-	if (!gtk_widget_get_realized (GTK_WIDGET (button)))
+	if (!GTK_WIDGET_REALIZED (button))
 		return;
 
 	if (button->priv->popup_shown)
@@ -349,7 +342,7 @@ face_tool_button_popup (GtkhtmlFaceToolButton *button)
 	gtk_toggle_tool_button_set_active (tool_button, TRUE);
 
 	/* Try to grab the pointer and keyboard. */
-	window = gtk_widget_get_window (button->priv->window);
+	window = button->priv->window->window;
 	status = gdk_pointer_grab (
 		window, TRUE,
 		GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
@@ -373,7 +366,7 @@ face_tool_button_popdown (GtkhtmlFaceToolButton *button)
 {
 	GtkToggleToolButton *tool_button;
 
-	if (!gtk_widget_get_realized (GTK_WIDGET (button)))
+	if (!GTK_WIDGET_REALIZED (button))
 		return;
 
 	if (!button->priv->popup_shown)
@@ -529,7 +522,7 @@ face_tool_button_init (GtkhtmlFaceToolButton *button)
 	gtk_window_set_resizable (GTK_WINDOW (window), FALSE);
 	gtk_window_set_type_hint (
 		GTK_WINDOW (window), GDK_WINDOW_TYPE_HINT_COMBO);
-	if (gtk_widget_is_toplevel (toplevel)) {
+	if (GTK_WIDGET_TOPLEVEL (toplevel)) {
 		gtk_window_group_add_window (
 			gtk_window_get_group (GTK_WINDOW (toplevel)),
 			GTK_WINDOW (window));
